# nanoLLM

[![PyPI](https://img.shields.io/pypi/v/nanoLLM.svg)](https://pypi.org/project/nanoLLM/)
[![Changelog](https://img.shields.io/github/v/release/jamesliu/nanoLLM?include_prereleases&label=changelog)](https://github.com/jamesliu/nanoLLM/releases)
[![Tests](https://github.com/jamesliu/nanoLLM/workflows/Test/badge.svg)](https://github.com/jamesliu/nanoLLM/actions?query=workflow%3ATest)
[![Documentation Status](https://readthedocs.org/projects/nanoLLM/badge/?version=stable)](http://nanoLLM.readthedocs.org/en/stable/?badge=stable)
[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://github.com/jamesliu/nanoLLM/blob/main/LICENSE)

nanoLLM is a Python package that provides a flexible and efficient implementation to create LLM bots over extensible dataset. 

## Installation

You can install nanoLLM directly from PyPI using pip:

```bash
pip install nanoLLM
```

Alternatively, you can clone the repository and install from source:

```bash
git clone https://github.com/jamesliu/nanoLLM.git
cd nanoLLM
pip install .
```

## Usage


## Documentation

Full documentation is available [here](https://nanoLLM.readthedocs.io/en/latest/).

## Contributing

We welcome contributions to nanoLLM! If you're interested in contributing, please see our [contribution guidelines](./CONTRIBUTING.md) and [code of conduct](./CODE_OF_CONDUCT.md).

## License

nanoLLM is licensed under the Apache License 2.0. See the [LICENSE](./LICENSE) file for more details.

## Support

For support, questions, or feature requests, please open an issue on our [GitHub repository](https://github.com/jamesliu/nanoLLM/issues) or contact the maintainers.

## Changelog

See the [releases](https://github.com/jamesliu/nanoLLM/releases) page for a detailed changelog of each version.


